@@ -1,4 +1,3 @@
-import ckan.plugins.toolkit as tk
 from ckanext.toolbelt.decorators import Collector
 
 auth, get_auth_functions = Collector("files").split()
@@ -20,7 +19,5 @@ def file_delete(context, data_dict):
 
 
 @auth
-@tk.auth_allow_anonymous_access
-@tk.side_effect_free
 def file_show(context, data_dict):
-    {"success": True}
+    {"success": False}
