@@ -2,18 +2,18 @@ import ckan.plugins.toolkit as tk
 from ckan.logic.schema import validator_args
 
 
-CONFIG_KIND = "ckanext.files.kind.default"
+CONFIG_KIND = "ckanext.files.default.kind"
 DEFAULT_KIND = "ckanext_files_file"
 
 
 @validator_args
 def file_create(
-    ignore_empty, dict_only, not_empty, unicode_safe, default, ignore
+        ignore_empty, dict_only, not_empty, unicode_safe, default, ignore, not_missing
 ):
     default_kind = tk.config.get(CONFIG_KIND, DEFAULT_KIND)
     return {
         "name": [not_empty, unicode_safe],
-        "upload": [not_empty],
+        "upload": [not_missing],
         "kind": [default(default_kind), unicode_safe],
         "extras": [ignore_empty, dict_only],
         "__extras": [ignore],
